semantic_analyzer

Function semantic_analyzer 

pub fn semantic_analyzer(
    pipeline: &mut PipelineData<'_>,
) -> Result<(), DCReadError>
Takes in the Abstract Syntax Trees from the last stage of the pipeline and outputs error diagnostics if any issues are found.