pub fn semantic_analyzer(
pipeline: &mut PipelineData<'_>,
) -> Result<(), DCReadError>Expand description
Takes in the Abstract Syntax Trees from the last stage of the pipeline
and outputs error diagnostics if any issues are found.
pub fn semantic_analyzer(
pipeline: &mut PipelineData<'_>,
) -> Result<(), DCReadError>Takes in the Abstract Syntax Trees from the last stage of the pipeline
and outputs error diagnostics if any issues are found.